=================================
Generate pages with metric tables
=================================

.. automodule:: abed.html.metric_tables
    :members:
    :undoc-members:
    :show-inheritance:
